@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # gdb-like "backtrace" debugger command
 #
-#   Copyright (C) 2008, 2016, 2018 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2008, 2016, 2018, 2019 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -24,9 +24,9 @@
 _Dbg_help_add backtrace \
 '**backtrace** [*opts*] [*count*]
 
-Print backtrace of all stack frames, or innermost *count* frames.
+Print backtrace of all stack frames, or inner-most *count* frames.
 
-With a negative argument, print outermost -*count* frames.
+With a negative argument, print outer-most -*count* frames.
 
 An arrow indicates the "current frame". The current frame determines
 the context used for many debugger commands such as expression
