@@ -48,7 +48,7 @@ Often when one is stopped at the line of the first part of an "if",
 "elif", "case", "return", "while" compound statement or an assignment
 statement, one wants to eval is just the expression portion.  For
 this, use eval?. Actually, any alias that ends in ? which is aliased
-to eval will do thie same thing.
+to eval will do the same thing.
 
 If no string is given, we run the string from the current source code
 about to be run. If the command ends `?` (via an alias) and no string is
@@ -68,7 +68,7 @@ typeset -i _Dbg_show_eval_rc; _Dbg_show_eval_rc=1
 
 _Dbg_do_eval() {
 
-    print "0=$_Dbg_dollar_0" > "$_Dbg_evalfile"
+    print "0=\"$_Dbg_dollar_0\"" > "$_Dbg_evalfile"
     print ". ${_Dbg_libdir}/lib/set-d-vars.sh" >> "$_Dbg_evalfile"
     print '_Dbg_rc=$?' >> "$_Dbg_evalfile"
 
@@ -117,6 +117,7 @@ _Dbg_do_eval() {
         _Dbg_set_dol_q $_Dbg_debugged_exit_code
         . $_Dbg_evalfile
     fi
+    _Dbg_rc=$?
     (( _Dbg_show_eval_rc )) && _Dbg_msg "\$? is $_Dbg_rc"
     # We've reset some variables like IFS and PS4 to make eval look
     # like they were before debugger entry - so reset them now.
