@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # frame.sh - gdb-like "frame" debugger commands
 #
-#   Copyright (C) 2008, 2010-2011, 2014, 2016 Rocky Bernstein
+#   Copyright (C) 2008, 2010-2011, 2014, 2016, 2018 Rocky Bernstein
 #   rocky@gnu.org
 #
 #   This program is free software; you can redistribute it and/or
@@ -28,7 +28,7 @@ fi
 _Dbg_help_add frame \
 '**frame** [*frame-number*].
 
-Change the current frame to frame *frame-numbrer* if specified, or the
+Change the current frame to frame *frame-number* if specified, or the
 most-recent frame, 0, if no frame number specified.
 
 A negative number indicates the position from the other or
