@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # set.sh - debugger settings
 #
-#   Copyright (C) 2008, 2010-2011, 2014 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2008, 2010-2011, 2014, 2020 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -37,6 +37,7 @@ typeset -A _Dbg_debugger_set_commands
 typeset -A _Dbg_command_help_set
 
 typeset -i _Dbg_set_autoeval=0     # Evaluate unrecognized commands?
+typeset -i _Dbg_set_autolist=0     # SHow listing when stopped
 typeset -i _Dbg_set_listsize=10    # How many lines in a listing?
 
 _Dbg_help_add set ''  # Help routine is elsewhere
@@ -71,6 +72,9 @@ _Dbg_do_set_internal() {
 	force | dif | diff | differ | different )
             _Dbg_set_onoff "$1" 'different'
             ;;
+	filename-display )
+            _Dbg_do_set_filename_display "$1"
+            ;;
 	inferior-tty )
             _Dbg_set_tty "$@"
             ;;
