@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # "set basename" debugger command
 #
-#   Copyright (C) 2011 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2011, 2014, 2016, 2020 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -18,8 +18,32 @@
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
 #   MA 02111 USA.
 
+if [[ 0 == ${#funcfiletrace[@]} ]] ; then
+    dirname=${0%/*}
+    [[ $dirname == $0 ]] && top_dir='../..' || top_dir=${dirname}/../..
+    for lib_file in help alias ; do source "$top_dir/lib/${lib_file}.sh"; done
+    typeset -A _Dbg_command_help_set
+    typeset -A _Dbg_debugger_set_commands
+fi
+
+typeset -A _Dbg_complete_level_2_data
+_Dbg_complete_level_2_data[set_basename]='on off'
+
 _Dbg_help_add_sub set basename \
-'Set short filenames (the basename) in debug output'
+'**set basename** [**on**|**off**]
+
+Set short filenames (the basename) in debug output.
+
+*This command is deprecated since gdb now has ``set filename-display`` which does the same thing.*
+
+So use ``set filename-display``.
+
+
+See also:
+---------
+
+**set filename-display**, and  **show basename**
+'
 
 _Dbg_do_set_basename() {
     _Dbg_set_onoff "$1" 'basename'
