@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # "set debug" debugger command
 #
-#   Copyright (C) 2011 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2011, 2014 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -18,6 +18,17 @@
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
 #   MA 02111 USA.
 
+if [[ 0 == ${#funcfiletrace[@]} ]] ; then
+    dirname=${0%/*}
+    [[ $dirname == $0 ]] && top_dir='../..' || top_dir=${dirname}/../..
+    for lib_file in help alias ; do source "$top_dir/lib/${lib_file}.sh"; done
+    typeset -A _Dbg_command_help_set
+    typeset -A _Dbg_debugger_set_commands
+fi
+
+typeset -A _Dbg_complete_level_2_data
+_Dbg_complete_level_2_data[set_debug]='on off'
+
 _Dbg_help_add_sub set debug \
 'Set debug the debugger' 1
 
