@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # show.sh - Show debugger settings
 #
-#   Copyright (C) 2008, 2010-2011, 2014
+#   Copyright (C) 2008, 2010-2011, 2014, 2019-2020, 2023
 #   Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
@@ -15,7 +15,7 @@
 #   General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with This program; see the file COPYING.  If not, write to
+#   along with this program; see the file COPYING.  If not, write to
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
 #   MA 02111 USA.
 
@@ -38,144 +38,163 @@ _Dbg_help_add show ''  # Help routine is elsewhere
 
 # Load in "show" subcommands
 for _Dbg_file in ${_Dbg_libdir}/command/show_sub/*.sh ; do
-    source $_Dbg_file
+    source "$_Dbg_file"
 done
 _Dbg_complete_level_1_data[show]=$(echo ${(kM)_Dbg_debugger_show_commands})
 
 _Dbg_do_show() {
-    _Dbg_do_show_internal $@
+    _Dbg_help_show $@
     return $?
 }
 
-_Dbg_do_show_internal() {
+_Dbg_help_show() {
+
+    if (( $# == 0 )) ; then
+        typeset list
+        list=(${(ki)_Dbg_command_help_show[@]})
+        typeset subcmd
+        for subcmd in ${list[@]}; do
+            _Dbg_help_show $subcmd 1
+        done
+        return 0
+    fi
+
     typeset show_cmd=$1
     typeset label=$2
 
-    # Warranty, copying, directories, and aliases are omitted below.
-    typeset subcmds='annotate args autoeval autolist basename debug editing force history listsize prompt trace-commands width'
-
-    if [[ -z $show_cmd ]] ; then
-        typeset thing
-        for thing in $subcmds ; do
-            _Dbg_do_show $thing 1
-        done
-        return 0
-    elif [[ -n ${_Dbg_debugger_show_commands[$show_cmd]} ]] ; then
-	[[ -n ${_Dbg_show_nolist[$thing]} ]] || \
+    if [[ -n "${_Dbg_debugger_show_commands[$show_cmd]}" ]] ; then
+        if [[ -z $label ]] ; then
             ${_Dbg_debugger_show_commands[$show_cmd]} $label
-        return $?
+            return $?
+        else
+            label=$(printf "show %-12s-- " $subcmd)
+        fi
     fi
 
     case $show_cmd in
+        al | ali | alia | alias | aliase | aliases )
+            _Dbg_msg \
+                "${label}Show list of aliases currently in effect."
+            ;;
         ar | arg | args )
             [[ -n $label ]] && label='args:     '
             _Dbg_msg \
                 "${label}Argument list to give script when debugged program starts is:\n" \
                 "      \"${_Dbg_script_args[@]}\"."
-            return 0
             ;;
         an | ann | anno | annot | annota | annotat | annotate )
-            [[ -n $label ]] && label='annotate: '
             _Dbg_msg \
-                "${label}Annotation_level is $_Dbg_set_annotate."
-            return 0
+                "${label}Show annotation_level"
             ;;
         autoe | autoev | autoeva | autoeval )
-            [[ -n $label ]] && label='autoeval: '
             _Dbg_msg \
                 "${label}Evaluate unrecognized commands is" $(_Dbg_onoff $_Dbg_set_autoeval)
-            return 0
             ;;
         autol | autoli | autolis | autolist )
-            [[ -n $label ]] && label='autolist: '
-            typeset onoff="on."
-            [[ -z ${_Dbg_cmdloop_hooks["list"]} ]] && onoff='off.'
             _Dbg_msg \
-                "${label}Auto run of 'list' command is ${onoff}"
-            return 0
+                "${label}Auto run a 'list' command is" $(_Dbg_onoff $_Dbg_set_autolist)
             ;;
         b | ba | bas | base | basen | basena | basenam | basename )
-            [[ -n $label ]] && label='basename: '
             _Dbg_msg \
-                "${label}Show short filenames (the basename) in debug output is" $(_Dbg_onoff $_Dbg_set_basename)
-            return 0
+                "${label}Show if we are are to show short or long filenames."
+            ;;
+        com | comm | comma | comman | command | commands )
+            _Dbg_msg \
+                "${label}Show the history of commands you typed."
+            ;;
+        con | conf | confi | confir | confirm )
+            _Dbg_msg \
+                "${label}confirm dangerous operations" $(_Dbg_onoff $_Dbg_set_confirm)
+            ;;
+        cop | copy| copyi | copyin | copying )
+            _Dbg_msg \
+                "${label}Conditions for redistributing copies of debugger."
             ;;
         dir|dire|direc|direct|directo|director|directori|directorie|directories)
-            typeset list=${_Dbg_dir[0]}
-            typeset -i n=${#_Dbg_dir[@]}
-            typeset -i i
-            for (( i=1 ; i < n; i++ )) ; do
-                list="${list}:${_Dbg_dir[i]}"
-            done
-
-            _Dbg_msg "Source directories searched: $list"
-            return 0
+	    if [[ -n $label ]]; then
+		_Dbg_msg \
+                    "${label}Show the search path for finding source files."
+	    else
+		typeset list=${_Dbg_dir[0]}
+		typeset -i n=${#_Dbg_dir[@]}
+		typeset -i i
+		for (( i=1 ; i < n; i++ )) ; do
+                    list="${list}:${_Dbg_dir[i]}"
+		done
+		_Dbg_msg "Source directories searched: $list"
+	    fi
+            ;;
+        d|de|deb|debu|debug|debugg|debugger|debuggi|debuggin|debugging )
+            _Dbg_msg \
+                "${label}Show if we are set to debug the debugger."
+            ;;
+        editing )
+            _Dbg_msg \
+                "${label}Show editing of command lines and edit style."
+            ;;
+        filename-display )
+            _Dbg_msg \
+                "${label}filename display."
             ;;
         force | diff | differ | different )
-            [[ -n $label ]] && label='different: '
             _Dbg_msg \
                 "${label}Show stepping forces a new line is" $(_Dbg_onoff $_Dbg_set_different)
+            ;;
+        highlight )
+            _Dbg_msg \
+                "${label}Show if we syntax highlight source listings."
+            ;;
+        history )
+            _Dbg_msg \
+                "${label}Show if we are recording command history."
             return 0
             ;;
         lin | line | linet | linetr | linetra | linetrac | linetrace )
-            [[ -n $label ]] && label='line tracing: '
-            typeset onoff="off."
-            (( _Dbg_set_linetrace != 0 )) && onoff='on.'
             _Dbg_msg \
-                "${label}Show line tracing is" $onoff
-            _Dbg_msg \
-                "${label}Show line trace delay is ${_Dbg_linetrace_delay}."
-            return 0
+                "${label}Show whether to trace lines before execution."
             ;;
-
         lis | list | lists | listsi | listsiz | listsize )
-            [[ -n $label ]] && label='listsize: '
             _Dbg_msg \
                 "${label}Number of source lines ${_Dbg_debugger_name} will list by default is" \
                 "$_Dbg_set_listsize."
-            return 0
             ;;
 
-        lo | log | logg | loggi | loggin | logging )
-            shift
-            _Dbg_do_show_logging $*
-            ;;
         p | pr | pro | prom | promp | prompt )
-            [[ -n $label ]] && label='prompt:   '
+	    # Note this is different from "help show prompt" output
             _Dbg_msg \
-                "${label}${_Dbg_debugger_name}'s prompt is:\n" \
-                "      \"$_Dbg_prompt_str\"."
-            return 0
+                "${label}Show ${_Dbg_debugger_name}'s command prompt."
+            ;;
+        st | sty | styl | style )
+            _Dbg_msg_nocr \
+                "${label}Set pygments highlighting style is "
+            if [[ -z $_Dbg_set_style ]] ; then
+                _Dbg_msg 'off.'
+            else
+		_Dbg_msg "${_Dbg_set_style}"
+            fi
             ;;
         sho|show|showc|showco|showcom|showcomm|showcomma|showcomman|showcommand )
-            [[ -n $label ]] && label='showcommand: '
+            [[ -n $label ]] && label='set showcommand -- '
             _Dbg_msg \
-                "${label}Show commands in debugger prompt is" \
-                "$_Dbg_set_show_command."
-            return 0
+                "${label}Set showing the command to execute is $_Dbg_set_show_command."
             ;;
-        t|tr|tra|trac|trace|trace-|tracec|trace-co|trace-com|trace-comm|trace-comma|trace-comman|trace-command|trace-commands )
-            [[ -n $label ]] && label='trace-commands: '
+        t|tr|tra|trac|trace|trace-|trace-c|trace-co|trace-com|trace-comm|trace-comma|trace-comman|trace-command|trace-commands )
             _Dbg_msg \
-                "${label}State of command tracing is" \
-                "$_Dbg_set_trace_commands."
-            return 0
+                'show trace-commands -- Show if we are echoing debugger commands'
             ;;
         v | ve | ver | vers | versi | versio | version )
             _Dbg_do_show_version
-            return 0
+            ;;
+        wa | war | warr | warra | warran | warrant | warranty )
+            _Dbg_msg \
+                "${label}Various kinds of warranty you do not have."
             ;;
         wi | wid | width )
-            [[ -n $label ]] && label='width: '
             _Dbg_msg \
                 "${label}Line width is $_Dbg_set_linewidth."
-            return 0
             ;;
-        *)
-            _Dbg_errmsg "Unknown show subcommand: $show_cmd"
-            _Dbg_errmsg "Show subcommands are:"
-            typeset -a list; list=(${subcmds[@]})
-            _Dbg_list_columns '  ' _Dbg_errmsg
-            return -1
+        * )
+            _Dbg_msg \
+                "Undefined show command: \"$show_cmd\".  Try \"help show\"."
     esac
 }
