@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # "show debug" debugger command
 #
-#   Copyright (C) 2010, 2011 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2010-2011, 2019 Rocky Bernstein <rocky@gnu.org>
 #
 #   bashdb is free software; you can redistribute it and/or modify it under
 #   the terms of the GNU General Public License as published by the Free
@@ -18,7 +18,9 @@
 #   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
 
 _Dbg_help_add_sub show debug \
-"Show if we are set to debug the debugger." 1
+"**show debug**
+
+Show if we are set to debug the debugger." 1
 
 _Dbg_do_show_debug() {
     [[ -n $label ]] && label='debug: '
