@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # "show highlight" debugger command
 #
-#   Copyright (C) 2011, 2014-2016 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2011, 2014-2016, 2019 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -19,7 +19,9 @@
 #   MA 02111 USA.
 
 _Dbg_help_add_sub show highlight \
-"Show terminal highlighting" 1
+"**show highlight**
+
+Show terminal highlighting" 1
 
 _Dbg_do_show_highlight() {
     typeset label="$1"
