@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # gdb-like "source" command.
 #
-#   Copyright (C) 2002-2004, 2006, 2008, 2010, 2016
+#   Copyright (C) 2002-2004, 2006, 2008, 2010, 2016, 2023
 #   Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
@@ -36,10 +36,10 @@ _Dbg_do_source() {
 
     typeset filename
     _Dbg_tilde_expand_filename "$1"
-    if [[ -r $filename ]] || [[ "$filename" == '/dev/stdin' ]] ; then
+    if [[ -r "$filename" ]] || [[ "$filename" == '/dev/stdin' ]] ; then
         # Redirect std input to new file and save new descriptor number
-        exec {_Dbg_fdi}< $filename
-        # Save descriptor number and assocated file name.
+        exec {_Dbg_fdi}< "$filename"
+        # Save descriptor number and associated file name.
         _Dbg_fd+=($_Dbg_fdi)
         _Dbg_cmdfile+=("$filename")
     else
