@@ -1,4 +1,4 @@
-# -*- shell-script -*-
+#  -*- shell-script -*-
 # hook.sh - Debugger trap hook
 #
 #   Copyright (C) 2008, 2009, 2010, 2011, 2018
@@ -28,6 +28,9 @@ typeset -i _Dbg_QUIT_LEVELS=0     # Number of nested shells we have to exit
 # Return code that debugged program reports
 typeset -i _Dbg_program_exit_code=0
 
+# Number of statements to skip before entering the debugger if greater than 0
+typeset -i _Dbg_skip_ignore=0
+
 # This is the main hook routine that gets called before every statement.
 # It's the function called via trap DEBUG.
 function _Dbg_trap_handler {
@@ -50,6 +53,8 @@ function _Dbg_trap_handler {
     typeset -i _Dbg_debugged_exit_code=$1
     shift
 
+    _Dbg_dollar_0=$1
+    shift
     # Populate _Dbg_arg with $1, $2, etc.
     typeset -a _Dbg_arg
     _Dbg_arg=($@)   # Does this require shword split off?
@@ -77,8 +82,9 @@ function _Dbg_trap_handler {
 	if ((! _Dbg_skipping_fn )) ; then
 	    ((_Dbg_skip_ignore--))
 	    _Dbg_write_journal "_Dbg_skip_ignore=$_Dbg_skip_ignore"
-	    _Dbg_set_to_return_from_debugger 2
-	    return 2 # 2 indicates skip statement.
+	    # Set to skip instruction
+	    set -o errexit
+	    return
 	fi
     fi
 
@@ -179,7 +185,7 @@ _Dbg_hook_action_hit() {
 	if (( linenos[_Dbg_i] == lineno )) ; then
 	    (( _Dbg_action_num = action_nos[_Dbg_i] ))
 	    stmt="${_Dbg_action_stmt[$_Dbg_action_num]}"
-  	    . ${_Dbg_libdir}/lib/set-d-vars.sh
+  	    . "${_Dbg_libdir}/lib/set-d-vars.sh"
   	    eval "$stmt"
 	    # We've reset some variables like IFS and PS4 to make eval look
 	    # like they were before debugger entry - so reset them now.
@@ -231,6 +237,10 @@ _Dbg_hook_enter_debugger() {
     _Dbg_print_location_and_command
     _Dbg_process_commands
     _Dbg_set_to_return_from_debugger $?
+    if (( $_Dbg_skip_ignore != 0 )) ; then
+	# Set to skip instruction
+	set -o errexit
+    fi
     return $_Dbg_rc # _Dbg_rc set to $? by above
 }
 
@@ -247,14 +257,13 @@ _Dbg_cleanup() {
 
 }
 
-# Follows bashdb which reports:
-# Somehow we can't put this in _Dbg_cleanup and have it work.
-# I am not sure why.
+# Follows zshdb
+# FIXME: In bash we can't put this in _Dbg_cleanup and have it work.
+# I am not sure why. This may or be applicable here.
 _Dbg_cleanup2() {
     [[ -f "$_Dbg_evalfile" ]] && rm -f "$_Dbg_evalfile" 2>/dev/null
     _Dbg_erase_journals
     trap - EXIT
-    ls -l ${_Dbg_journal}
 }
 
 _Dbg_hook_error_handler() {
