@@ -17,7 +17,7 @@
 #   with zshdb; see the file COPYING.  If not, write to the Free Software
 #   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
 
-typeset -r _Dbg_info_cmds='breakpoints display files line program source stack variables warranty'
+typeset -r _Dbg_info_cmds='breakpoints display files functions line program source stack variables warranty'
 
 _Dbg_info_help() {
 
@@ -68,9 +68,14 @@ _Dbg_info_help() {
 		    'info files -- Source files in the program'
 		return 0
 		;;
+	    'fu' | fun | func | funct | functi | functio | 'function' | functions )
+		_Dbg_msg \
+		    'info functions -- Functions defined in the program'
+		return 0
+		;;
 	    l | li| lin | line )
 		_Dbg_msg \
-		    'info line -- list current line number and and file name'
+		    'info line -- List current line number and and file name'
 		return 0
 		;;
 	    p | pr | pro | prog | progr | progra | program )
